==> synchros1s2-0.0.23.tar.gz: synchros1s2-0.0.23/domains/synchronisation.py <==
import logging
import os
import time

import config
from domains.issue import Issue
from implementations.implementation_issue_S1 import IssueImplementationS1
from implementations.implementation_issue_S2 import IssueImplementationS2
from implementations.implementation_table_correpondance_key_id import verifier_existence_id, save_correspondance_table,rebuild_correspondence_table,get_correspondence_table,save_correspondence,save_correspondence_dict

logging.basicConfig(filename=config.log_file, level=logging.INFO, format=config.log_format)


class Synchronisation:
    issue1 = IssueImplementationS1.issue1_factory(summary='', description='', updated=None, status='')

    @staticmethod
    def synchronisation_S2_S1():
        if not(os.path.exists(config.table_correspondance_file)) or os.path.getsize(config.table_correspondance_file) == 0:
            print("try to rebuils correspondence table ")
            rebuild_correspondence_table()
        issues_in_S2 = IssueImplementationS2.all_filtre_id_et_updated()
        for issue_in_S2 in issues_in_S2:
            miror_S1_de_S2 = issue_in_S2.miror
            if miror_S1_de_S2 is None:
                issue_complet_S2 = issue_in_S2.get()
                issue_S2_convertie_en_S1 = IssueImplementationS1.convertirS_enS_(issue_complet_S2)
                issue_complet_S2.miror = issue_S2_convertie_en_S1.save()
                issue_complet_S2.update()
                logging.info(f"Ajout du ticket N°{issue_complet_S2.key} dans S1")

    

            # elif miror_S1_de_S2 and Issue.date_S1_entre_date_derniere_synchro_et_date_S2(miror_S1_de_S2.updated,
            #                                                                           issue_in_S2.updated):
            #     issue_complet_S2_convertie_en_S1.update()
            #     logging.info(f"Modification du ticket N°{issue_in_S2.key} dans S1")

            # issue_in_S1 = Issue.trouver(issue_in_S2, issues_in_S1)
            # issue_to_save_or_update = IssueImplementationS1.convertirS_enS_(issue_in_S2.get())
            # if issue_in_S1 is None:
            #     issue_to_save_or_update.save()
            #     logging.info(f"Ajout du ticket N°{issue_in_S2.key} dans S1")
            #     # Changer fonction date_S1_entre_date_derniere_synchro_et_date_S2 en utilisant mirror
            # elif issue_in_S1 and Issue.date_S1_entre_date_derniere_synchro_et_date_S2(issue_in_S1.updated,
            #                                                                           issue_in_S2.updated):
            #     issue_to_save_or_update.update()
            #     logging.info(f"Modification du ticket N°{issue_in_S2.key} dans S1")

    @staticmethod
    def synchronisation_S1_S2():  # Créer a partir de S1 tout les S2
        issues_in_S1 = IssueImplementationS1.all_filtre_id_et_updated()
        for issue_in_S1 in issues_in_S1:
            if not verifier_existence_id(issue_in_S1.id):
                issue_complet_S1 = IssueImplementationS1.find_by_id(issue_in_S1.id)
                correspondance_S2 = IssueImplementationS2.convertirS_enS_(issue_complet_S1)
                correspondance_S2.miror = issue_in_S1
                key = correspondance_S2.save()
                save_correspondance_table(key, issue_in_S1.id)

    @staticmethod
    def synchronisation_S1_S2_v2():
        if not(os.path.exists(config.table_correspondance_file)) or os.path.getsize(config.table_correspondance_file) == 0:
            print("try to rebuils correspondence table ")
            rebuild_correspondence_table()
        table = get_correspondence_table()
        table_id_list = table.values()
        print('table list ....',table_id_list)
        issue = IssueImplementationS1.issue1_factory("","",None,"")
        issue_list = issue.all()
        new_correspondences = {}
        i = 10
        for issue in issue_list:
            print(issue)
            if str(issue.id) not in table_id_list and i > 4:
                print("issue not in issue_list",issue.id)
                miror = IssueImplementationS2(summary=issue.summary,description=issue.description, status=issue.status)
                print("miror",miror)
                miror.miror = issue
                key = miror.save()
                print("new key",key)
                new_correspondences[key] = issue.id
                #save_correspondence(key,issue.id)        # tout save à la fois ?  chaque save ouvre le fichier 
                i-= 1
                print("Iteration numero ....",i+1)
        save_correspondence_dict(new_correspondences)      
        

if __name__ == "__main__":
    Synchronisation.synchronisation_S2_S1()

==> synchros1s2-0.0.38.tar.gz: synchros1s2-0.0.38/domains/synchronisation.py <==
import logging
import os

from config import config
from implementations.implementation_issue_S1 import IssueImplementationS1
from implementations.implementation_issue_S2 import IssueImplementationS2
from implementations.implementation_table_correpondance_key_id import verifier_existence_id, save_correspondance_table,rebuild_correspondence_table,get_correspondence_table, \
    save_correspondence_dict

logging.basicConfig(filename=config.log_file, level=logging.INFO, format=config.log_format)


class Synchronisation:
    issue1 = IssueImplementationS1.issue1_factory(summary='', description='', updated=None, status='')

    @staticmethod
    def synchronisation_S2_S1():
        if not(os.path.exists(config.table_correspondance_file)) or os.path.getsize(config.table_correspondance_file) == 0:
            print("try to rebuils correspondence table ")
            rebuild_correspondence_table()
        issues_in_S2 = IssueImplementationS2.all_filtre_id_et_updated()
        for issue_in_S2 in issues_in_S2:
            miror_S1_de_S2 = issue_in_S2.miror
            if miror_S1_de_S2 is None:
                issue_complet_S2 = issue_in_S2.get()
                issue_S2_convertie_en_S1 = IssueImplementationS1.convertirS_enS_(issue_complet_S2)
                issue_complet_S2.miror = issue_S2_convertie_en_S1.save()
                issue_complet_S2.update()
                logging.info(f"Ajout du ticket N°{issue_complet_S2.key} dans S1")

    

            # elif miror_S1_de_S2 and Issue.date_S1_entre_date_derniere_synchro_et_date_S2(miror_S1_de_S2.updated,
            #                                                                           issue_in_S2.updated):
            #     issue_complet_S2_convertie_en_S1.update()
            #     logging.info(f"Modification du ticket N°{issue_in_S2.key} dans S1")

            # issue_in_S1 = Issue.trouver(issue_in_S2, issues_in_S1)
            # issue_to_save_or_update = IssueImplementationS1.convertirS_enS_(issue_in_S2.get())
            # if issue_in_S1 is None:
            #     issue_to_save_or_update.save()
            #     logging.info(f"Ajout du ticket N°{issue_in_S2.key} dans S1")
            #     # Changer fonction date_S1_entre_date_derniere_synchro_et_date_S2 en utilisant mirror
            # elif issue_in_S1 and Issue.date_S1_entre_date_derniere_synchro_et_date_S2(issue_in_S1.updated,
            #                                                                           issue_in_S2.updated):
            #     issue_to_save_or_update.update()
            #     logging.info(f"Modification du ticket N°{issue_in_S2.key} dans S1")

    @staticmethod
    def synchronisation_S1_S2():  # Créer a partir de S1 tout les S2
        issues_in_S1 = IssueImplementationS1.all_filtre_id_et_updated()
        for issue_in_S1 in issues_in_S1:
            if not verifier_existence_id(issue_in_S1.id):
                issue_complet_S1 = IssueImplementationS1.find_by_id(issue_in_S1.id)
                correspondance_S2 = IssueImplementationS2.convertirS_enS_(issue_complet_S1)
                correspondance_S2.miror = issue_in_S1
                key = correspondance_S2.save()
                save_correspondance_table(key, issue_in_S1.id)

    @staticmethod
    def synchronisation_S1_S2_v2():
        if not(os.path.exists(config.table_correspondance_file)) or os.path.getsize(config.table_correspondance_file) == 0:
            print("try to rebuils correspondence table ")
            rebuild_correspondence_table()
        table = get_correspondence_table()
        table_id_list = table.values()
        print('table list ....',table_id_list)
        issue = IssueImplementationS1.issue1_factory("","",None,"")
        issue_list = issue.all()
        new_correspondences = {}
        i = 10
        for issue in issue_list:
            print(issue)
            if str(issue.id) not in table_id_list and i > 4:
                print("issue not in issue_list",issue.id)
                miror = IssueImplementationS2(summary=issue.summary,description=issue.description, status=issue.status)
                print("miror",miror)
                miror.miror = issue
                key = miror.save()
                print("new key",key)
                new_correspondences[key] = issue.id
                #save_correspondence(key,issue.id)        # tout save à la fois ?  chaque save ouvre le fichier 
                i-= 1
                print("Iteration numero ....",i+1)
        save_correspondence_dict(new_correspondences)      
        

if __name__ == "__main__":
    Synchronisation.synchronisation_S2_S1()
